package com.ruoyi.rc.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.rc.mapper.TProgressMapper;
import com.ruoyi.rc.domain.TProgress;
import com.ruoyi.rc.service.ITProgressService;

/**
 * 进度Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@Service
public class TProgressServiceImpl implements ITProgressService 
{
    @Autowired
    private TProgressMapper tProgressMapper;

    /**
     * 查询进度
     * 
     * @param id 进度主键
     * @return 进度
     */
    @Override
    public TProgress selectTProgressById(Long id)
    {
        return tProgressMapper.selectTProgressById(id);
    }

    /**
     * 查询进度列表
     * 
     * @param tProgress 进度
     * @return 进度
     */
    @Override
    public List<TProgress> selectTProgressList(TProgress tProgress)
    {
        return tProgressMapper.selectTProgressList(tProgress);
    }

    /**
     * 新增进度
     * 
     * @param tProgress 进度
     * @return 结果
     */
    @Override
    public int insertTProgress(TProgress tProgress)
    {
        return tProgressMapper.insertTProgress(tProgress);
    }

    /**
     * 修改进度
     * 
     * @param tProgress 进度
     * @return 结果
     */
    @Override
    public int updateTProgress(TProgress tProgress)
    {
        return tProgressMapper.updateTProgress(tProgress);
    }

    /**
     * 批量删除进度
     * 
     * @param ids 需要删除的进度主键
     * @return 结果
     */
    @Override
    public int deleteTProgressByIds(Long[] ids)
    {
        return tProgressMapper.deleteTProgressByIds(ids);
    }

    /**
     * 删除进度信息
     * 
     * @param id 进度主键
     * @return 结果
     */
    @Override
    public int deleteTProgressById(Long id)
    {
        return tProgressMapper.deleteTProgressById(id);
    }
}
